<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>

SPDX-License-Identifier: GPL-2.0-or-later
-->

# fedrq.release_repo

!!! warning
    The `fedrq.release_repo` is a private, unstable API

::: fedrq.release_repo
